@@ -1,4 +1,3 @@
-import csv
 import logging
 import pandas as pd
 import pdfkit
@@ -27,7 +26,7 @@ class Converter:
     converter class to convert a list of dictionary objects to various formats
     """
     @staticmethod
-    def convert_to_csv(object_list, field_names, path):
+    def convert_to_csv(object_list, path):
         """
         converts list of dictionary objects to csv
          param object_list: list containing dictionary objects
@@ -40,8 +39,6 @@ class Converter:
             raise TypeError("list of dictionaries is expected as input for object_list parameter")
         if path is None:
             raise TypeError("path cannot be none")
-        if field_names is None:
-            raise TypeError("field_names cannot be none")
         try:
             dataframe = pd.DataFrame(data=object_list)
             dataframe.to_csv(path, index=False)
